Objects from the Class
"BaseLearner.Config" is a virtual Class: No objects may be created from it. "Regression.Config" is a base class for configuration classes of specific base learners, such as SVM.Regression.Config; therefore, there is typically no need to generate objects from this base class directly.Extends
Class "Regression.Config" extends class "BaseLearner.Config", directly.Methods
No methods defined with class "BaseLearner.Config" or "Regression.Config" in the signature.