Learn R Programming

EnsembleBase (version 1.0.0)

BaseLearner.Fit-methods: Generic S4 Method for Fitting Base Learners

Description

Each base learner must provide its concrete implementation of this generic method.

Usage

BaseLearner.Fit(object, formula, data, tmpfile=NULL, print.level=1, ...)

Arguments

object
An object of class BaseLearner.Config (must be a concrete implementation such as KNN.Regression.Config).
formula
Formula object expressing response and covariates.
data
Data frame containing response and covariates.
tmpfile
Filepath to save the estimation object to. If NULL, estimation object will not be saved to a file.
print.level
Controlling verbosity level during fitting.
...
Arguments to be passed to/from other methods.