Learn R Programming

EnsembleBase (version 1.0.0)

Regression.Integrator.Fit-methods: Generic Integrator Methods in Package EnsembleBase

Description

Generic methods that can be extended and used in constructing integrator algorithms by other packages.

Usage

Regression.Integrator.Fit(object, X, y, print.level=1)
Regression.Select.Fit(object, X, y, print.level=1)

Arguments

object
An object typically containing all configuration parameters of a particular integrator algorithm or operations.
X
Matrix of covariates.
y
Vector of response variables.
print.level
Verbosity level.