Arguments
ntot
Total number of observations in the data set to be partitioned.
nfold
Number of folds in the data partition.
npart
Number of random partitions to generate.
ids
Column names for the resulting partition matrix, used as partition ID.
formula
Formula object to use for extracting response variable from data set.
data
Data frame containing response variable as defined in formula.
file
Filepath from which to read an R object into memory (saved using the save function).
a,b
Vectors of equal length, used to calculate their RMSE distance.