Instance-class: Classes "Instance" and "Instance.List"
Description
A base learner Instance is a combination of a base learner configuration and data partition. Instances constitute the major input into the cross-validation-based functions such as Regression.CV.Batch.Fit. An Instance.List is a collection of instances, along with the underlying definition of data partitions referenced in the instance objects. The function make.instances is a convenient function for generating an instance list from all permutations of a given list of base learner configurations and data partitions.Objects from the Class
Objects can be created by calls of the form new("Instance", ...).Methods
No methods defined with class "Instance" in the signature.